@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 REC = """#!/bin/bash
 if [[ ! -f {TARGET_LOC} ]]; then
     mkdir -p {TARGET_LOC}/vault
@@ -10,10 +11,8 @@ cd {TARGET_LOC}
 echo "🍜 changed permission to root"
 SOLC_VERSION={SOLVER} solc --version
 
-
 echo "and then the compiler version should be... "
 
-
 {LISTP}
 
 cd {TARGET_LOC}/build && tar -czf {COMPRESSED_NAME} *.*
@@ -26,19 +25,15 @@ exit
 """
 
 TRANS_LOCAL = """#!/bin/bash
-
 # -----------------------------------------------
-if ! command -v abi-gen-uni &>/dev/null; then
-    echo "abi-gen-uni could not be found. please check the official source from: https://www.npmjs.com/package/easy-abi-gen"
-    cnpm i -g easy-abi-gen
-fi
+{PRE_HEAD}
 
 {LISTP}
 
 """
 ITEM = """
 echo "🍯 Compiling from {COMPILE_COIN} 🧀"
-SOLC_VERSION={SOLVER} solc --evm-version byzantium --allow-paths {SOLCPATH} -o build --bin --bin-runtime --abi --optimize --metadata --overwrite {COMPILE_COIN}
+SOLC_VERSION={SOLVER} solc --evm-version {EVMVERSION} --allow-paths {SOLCPATH} -o build --bin --bin-runtime --abi --optimize --metadata --overwrite {COMPILE_COIN}
 echo "=> 🍺🍺🍺 {COMPILE_COIN}"
 """
 
@@ -50,6 +45,7 @@ echo "=> 🍥🍥🍥 {COMPILE_COIN}"
 """
 
 ITEM_CP_LOCAL = """
+echo "==> 🚸 file system operation, move files.. 
 rm "{tolocation}"
 cp "{fromlocation}" "{tolocation}"
 """
@@ -80,16 +76,26 @@ abi-gen-uni --abibins "{target_abi}" --out "{outputfolder}" \
 
 echo "==> generate abi to typescript --> 🧊"
 """
-ITEM_TRANSPILE_GO="""
+ITEM_TRANSPILE_GO = """
 echo "==> 🚸 compile abi to golang"
-local SOL=$1
-local CLASSNAME=$2
-local GO_CONTRACT_SRC_PATH=$3
-if [[ ! -f $GO_CONTRACT_SRC_PATH/$CLASSNAME ]]; then
-    mkdir -p "$GO_CONTRACT_SRC_PATH/$CLASSNAME"
+if [[ ! -f {outputfolder} ]]; then
+    mkdir -p {outputfolder}
 fi
 
-abigen --abi "$BUILDPATH/build/$CLASSNAME.abi" --pkg $CLASSNAME --out "$GO_CONTRACT_SRC_PATH/$CLASSNAME/init.go"
+abigen --abi {target_abi} --pkg {classname} --type {classname} --out {outputfolder}/{classname}/init.go
 
 echo "==> generate abi to golang --> 🧊"
-"""
\ No newline at end of file
+"""
+
+PRE_HEAD = """
+
+if ! command -v abi-gen-uni &>/dev/null; then
+    echo "abi-gen-uni could not be found"
+    cnpm i -g easy-abi-gen
+fi
+
+if ! command -v abigen &>/dev/null; then
+    echo "abigen could not be found, please go check out: https://geth.ethereum.org/downloads/"
+    exit;
+fi
+"""
