@@ -1,8 +1,10 @@
 import os
 import re
 
+from tronpytool.compile import ITEM_TRANSPILE_GO
+
 from moody.paths import Paths
-from . import ITEM_CP_LOCAL, TRANS_LOCAL, ITEM_TRANSPILE_PYTHON, ITEM_TRANSPILE_TS
+from . import ITEM_CP_LOCAL, TRANS_LOCAL, ITEM_TRANSPILE_PYTHON, ITEM_TRANSPILE_TS, PRE_HEAD
 
 REG = r"(.+?)([A-Z])"
 
@@ -23,7 +25,7 @@ def filter_file_name(y: str) -> str:
     return classNameNew
 
 
-def buildCmdTsUpdate(p: Paths, pathName: str) -> str:
+def moveTsFiles(p: Paths, pathName: str) -> str:
     nameClass = filter_file_name(os.path.basename(pathName)).replace('.sol', '')
     fromp = "{}/codec/gen_ts/{}.ts".format(p.BUILDPATH, nameClass)
     top = "{}/{}/src/api/abi/{}.ts".format(p.BUILDPATH, p.WEB_DAPP_SRC, nameClass)
@@ -49,7 +51,19 @@ def buildCmdTs(p: Paths, pathName: str) -> str:
     )
 
 
-def wrapContent(tar: Paths, compile_list: list) -> str:
+def buildCmdGo(p: Paths, pathName: str) -> str:
+    based_name = os.path.basename(pathName)
+    class_name = filter_file_name(based_name).replace('.sol', '')
+    print("new new new new")
+    return ITEM_TRANSPILE_GO.format(
+        outputfolder=f"{p.BUILDPATH}/codec/gen_go",
+        target_abi=f"{p.BUILDPATH}/build/{based_name.replace('.sol', '')}.abi",
+        BUILDPATH=p.BUILDPATH,
+        classname=class_name
+    )
+
+
+def wrapContentTranspile(tar: Paths, compile_list: list) -> str:
     """
     wrap content
     :param tar:
@@ -61,6 +75,7 @@ def wrapContent(tar: Paths, compile_list: list) -> str:
         TARGET_LOC=tar.TARGET_LOC,
         COMPRESSED_NAME=tar.COMPRESSED_NAME,
         SOLVER=tar.SOLC_VER,
+        PRE_HEAD=PRE_HEAD
     )
 
 
@@ -76,8 +91,9 @@ def BuildLang(p: Paths, list_class_names: list) -> None:
     for v in list_class_names:
         k.append(buildCmdPy(p, v))
         k.append(buildCmdTs(p, v))
-        k.append(buildCmdTsUpdate(p, v))
+        k.append(buildCmdGo(p, v))
+        k.append(moveTsFiles(p, v))
     # ==================================================
     with open(p.workspaceFilename("localpile"), 'w') as f:
-        f.write(wrapContent(p, k))
+        f.write(wrapContentTranspile(p, k))
         f.close()
